@@ -1,3 +1,6 @@
 "anova.gamlist" <-
 function(object, ..., test = c("none", "Chisq", "F", "Cp"))
-anova.glmlist(object, test = test)
+{
+    test <- match.arg(test)
+    anova.glmlist(object, test = test)
+}
